using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.UIControls;
using CMS.SiteProvider;


public partial class CMSAdminControls_UI_SiteSelector : CMSUserControl
{
    #region "Private variables"

    private bool mEnabled = true;
    private bool mUseSiteNameForSelection = false;
    private string mSiteName = null;
    private int mSiteID = 0;
    private bool mAddAllItemsRecord = true;
    private string mDropdownCss = null;
    private string mWhereCondition = "";
    private bool mDisplayOnlyUserSites = false;

    #endregion


    /// <summary>
    /// Event fired when selected site change.
    /// </summary>
    public event EventHandler SelectedSiteChanged;


    #region "Public properties"

    /// <summary>
    /// Gets or sets the enabled state of the control
    /// </summary>
    public bool Enabled
    {
        get
        {
            return this.mEnabled;
        }
        set
        {
            this.mEnabled = value;
            this.drpSite.Enabled = value;
        }
    }


    /// <summary>
    /// Inner dropdown list css class.
    /// </summary>
    public string DropdownCss
    {
        get
        {
            return this.mDropdownCss;
        }
        set
        {
            this.mDropdownCss = value;
        }
    }


    /// <summary>
    /// Indicates whether the site name is used as selection value.
    /// </summary>
    public bool UseSiteNameForSelection
    {
        get
        {
            return this.mUseSiteNameForSelection;
        }
        set
        {
            this.mUseSiteNameForSelection = value;
        }
    }


    /// <summary>
    /// Indicates whether only user related sites are displayed in the selection.
    /// </summary>
    public bool DisplayOnlyUserSites
    {
        get
        {
            return this.mDisplayOnlyUserSites;
        }
        set
        {
            this.mDisplayOnlyUserSites = value;
        }
    }


    /// <summary>
    /// Gets or sets the Site name.
    /// </summary>
    public string SiteName
    {
        get
        {
            if (this.mUseSiteNameForSelection)
            {
                return ValidationHelper.GetString(this.drpSite.SelectedValue, "");
            }
            else
            {
                int id = ValidationHelper.GetInteger(this.drpSite.SelectedValue, 0);
                SiteInfo si = SiteInfoProvider.GetSiteInfo(id);
                if (si != null)
                {
                    return si.SiteName;
                }
                return "";
            }
        }
        set
        {
            if (this.mUseSiteNameForSelection)
            {
                SelectValue(value);
                this.mSiteName = value;
            }
            else
            {
                SiteInfo si = SiteInfoProvider.GetSiteInfo(value);
                if (si != null)
                {
                    SelectValue(si.SiteID.ToString());
                    this.mSiteID = si.SiteID;
                }
            }
        }
    }


    /// <summary>
    /// Gets or sets the Site ID.
    /// </summary>
    public int SiteID
    {
        get
        {
            if (this.mUseSiteNameForSelection)
            {
                string name = ValidationHelper.GetString(this.drpSite.SelectedValue, "");
                SiteInfo si = SiteInfoProvider.GetSiteInfo(name);
                if (si != null)
                {
                    return si.SiteID;
                }
                return 0;
            }
            else
            {
                return ValidationHelper.GetInteger(this.drpSite.SelectedValue, 0);
            }
        }
        set
        {
            if (this.mUseSiteNameForSelection)
            {
                SiteInfo si = SiteInfoProvider.GetSiteInfo(value);
                if (si != null)
                {
                    SelectValue(si.SiteName);
                    this.mSiteName = si.SiteName;
                }
            }
            else
            {
                SelectValue(value.ToString());
                this.mSiteID = value;
            }
        }
    }


    /// <summary>
    /// Gets or sets the field value.
    /// </summary>
    public object Value
    {
        get
        {
            if (this.mUseSiteNameForSelection)
            {
                return this.SiteName;
            }
            else
            {
                return this.SiteID;
            }
        }
        set
        {
            if (this.mUseSiteNameForSelection)
            {
                this.SiteName = ValidationHelper.GetString(value, "");
            }
            else
            {
                this.SiteID = ValidationHelper.GetInteger(value, 0);
            }
        }
    }


    /// <summary>
    /// Gets or sets the value which determines, whether to add all item record to the dropdownlist.
    /// </summary>
    public bool AddAllItemsRecord
    {
        get
        {
            return mAddAllItemsRecord;
        }
        set
        {
            mAddAllItemsRecord = value;
        }
    }


    /// <summary>
    /// Gets or sets WHERE condition to filter sites selected.
    /// </summary>
    public string WhereCondition
    {
        get 
        {
            return this.mWhereCondition;
        }
        set 
        {
            this.mWhereCondition = value;
        }
    }

    #endregion


    protected override void OnInit(EventArgs e)
    {
        if (!RequestHelper.IsPostBack())
        {
            if (!this.StopProcessing)
            {
                ReloadData();
            }
        }

        base.OnInit(e);
    }


    protected void Page_Load(object sender, EventArgs e)
    {
        //if ((!RequestHelper.IsPostBack()) && (drpSite.Items.Count == 0))
        //{
        //    if (!this.StopProcessing)
        //    {
        //        ReloadData();
        //    }
        //}
    }


    protected void Page_PreRender(object sender, EventArgs e)
    {
        if (!String.IsNullOrEmpty(this.DropdownCss))
        {
            this.drpSite.CssClass = this.DropdownCss;
        }
    }


    protected void drpSite_SelectedIndexChanged(object sender, EventArgs e)
    {
        // Fire event if someone registered
        if (this.SelectedSiteChanged != null) 
        {
            this.SelectedSiteChanged(sender, e);
        }
    }


    #region "Methods"

    /// <summary>
    /// Loads public status according to the control settings.
    /// </summary>
    public void ReloadData()
    {
        // Cleanup
        this.drpSite.ClearSelection();
        this.drpSite.SelectedValue = null;
        this.drpSite.Items.Clear();

        string where = "SiteStatus='RUNNING'";
        if (!string.IsNullOrEmpty(this.WhereCondition)) 
        {
            where += " AND (" + this.WhereCondition + ")";
        }

        // Populate the dropdownlist
        object sites = null;
        if (this.DisplayOnlyUserSites && !CMSContext.CurrentUser.IsGlobalAdministrator)
        {
            sites = UserInfoProvider.GetUserSites(CMSContext.CurrentUser.UserID, where, "SiteDisplayName", 0, null);
        }
        else
        {
            sites = SiteInfoProvider.GetSites(where, "SiteDisplayName");
        }
        this.drpSite.DataSource = sites;

        if (this.mUseSiteNameForSelection)
        {
            this.drpSite.DataValueField = "SiteName";
        }
        else
        {
            this.drpSite.DataValueField = "SiteID";
        }
        this.drpSite.DataTextField = "SiteDisplayName";
        this.drpSite.DataBind();

        // If user is global admin without site assigned use current site as selected
        if ((this.drpSite.Items.Count == 0) && CMSContext.CurrentUser.IsGlobalAdministrator) 
        {
            string value = (this.mUseSiteNameForSelection) ? CMSContext.CurrentSiteName : CMSContext.CurrentSiteID.ToString();        

            this.drpSite.Items.Add(new ListItem(CMSContext.CurrentSiteName, value));
        }

        // Add all record if needed
        if (this.AddAllItemsRecord)
        {
            this.drpSite.Items.Insert(0, new ListItem(ResHelper.GetString("General.SelectAll"), ""));
        }

        // Try to preselect the value
        if (this.mUseSiteNameForSelection)
        {
            SelectValue(this.mSiteName);
        }
        else
        {
            SelectValue(this.mSiteID.ToString());
        }
    }


    /// <summary>
    /// Tries to select the specified value in drpSite
    /// </summary>
    private void SelectValue(string val)
    {
        try
        {
            if (this.mUseSiteNameForSelection)
            {
                if (!String.IsNullOrEmpty(val))
                {
                    if (this.drpSite.Items.FindByValue(val) != null)
                    {
                        this.drpSite.SelectedValue = val;
                    }
                }
            }
            else
            {
                if (ValidationHelper.GetInteger(val, 0) != 0)
                {
                    if (this.drpSite.Items.FindByValue(val) != null)
                    {
                        this.drpSite.SelectedValue = val;
                    }
                }
            }
        }
        catch { }
    }

    #endregion
}
