using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.WorkflowEngine;
using CMS.Staging;
using CMS.UIControls;

using TreeNode = CMS.TreeEngine.TreeNode;

public partial class CMSDesk_Content_Properties_Alias_Edit : CMSDeskPage
{
    #region "Private variables"

    protected int aliasId = 0;
    protected int nodeId = 0;

    protected TreeNode node = null;
    protected TreeProvider tree = null;

    #endregion
    protected void Page_Load(object sender, EventArgs e)
    {       
        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"],0);

        if (nodeId > 0)
        {
            // Get the node
            tree = new TreeProvider(CMSContext.CurrentUser);
            node = tree.SelectSingleNode(nodeId);

            if (node != null)
            {
                // Check read permissions
                if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
                {
                    RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
                }
                // Check modify permissions
                else if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.Modify) == AuthorizationResultEnum.Denied)
                {                   
                    this.lblInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoeditdocument"), node.NodeAliasPath);
                    txtTrackCampaign.Enabled = false;
                    txtURLExtensions.Enabled = false;
                    txtURLPath.Enabled = false;
                    drpDocumentCulture.Enabled = false;
                }
                else
                {
                    lblInfo.Visible = false;
                }

                if (QueryHelper.GetInteger("saved", 0) == 1)
                {
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("general.changessaved");
                }
                
                lblDocumentCulture.Text = ResHelper.GetString("general.culture") + ResHelper.Colon;
                lblTrackCampaign.Text = ResHelper.GetString("doc.urls.trackcampaign") + ResHelper.Colon;
                lblURLPath.Text = ResHelper.GetString("doc.urls.urlpath") + ResHelper.Colon;
                lblURLExtensions.Text = ResHelper.GetString("doc.urls.urlextensions") + ResHelper.Colon;
                btnOK.Text = ResHelper.GetString("general.ok");
                valURLPath.ErrorMessage = ResHelper.GetString("doc.urls.requiresurlpath");


                // Initialiaze page title

                string urls = ResHelper.GetString("Properties.Urls");
                string urlsUrl = "~/CMSDesk/Content/Properties/Alias_List.aspx?nodeid=" + nodeId.ToString();
                string addAlias = ResHelper.GetString("doc.urls.addnewalias");                
                // initializes page title
                string[,] pageTitleTabs = new string[2, 3];
                pageTitleTabs[0, 0] = urls;
                pageTitleTabs[0, 1] = urlsUrl;
                pageTitleTabs[0, 2] = "";
                pageTitleTabs[1, 0] = addAlias;
                pageTitleTabs[1, 1] = "";
                pageTitleTabs[1, 2] = "";
                pageAlias.Breadcrumbs = pageTitleTabs;


                drpDocumentCulture.Items.Add(new ListItem(ResHelper.GetString("general.selectall"), ""));
                
                // Get all cultures 
                DataSet ds = new DataSet();
                ds = CultureInfoProvider.GetSiteCultures(CMS.CMSHelper.CMSContext.CurrentSiteName);

                if (ds != null)
                {
                    foreach (DataRow dr in ds.Tables[0].Rows)
                    {                        
                        drpDocumentCulture.Items.Add(new ListItem((string)dr["CultureName"],(string)dr["CultureCode"]));
                    }
                }
                 

                aliasId = ValidationHelper.GetInteger(Request.QueryString["aliasid"], 0);


                if (RequestHelper.IsPostBack())
                {
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("general.changessaved");
                }
                else
                {
                    drpDocumentCulture.SelectedValue = node.DocumentCulture;

                    // Edit existing alias
                    if (aliasId > 0)
                    {                        
                        DocumentAliasInfo dai = DocumentAliasInfoProvider.GetDocumentAliasInfo(aliasId);

                        if (dai != null)
                        {
                            txtTrackCampaign.Text = dai.AliasCampaign;
                            txtURLExtensions.Text = dai.AliasExtensions;
                            txtURLPath.Text = dai.AliasURLPath;
                            drpDocumentCulture.SelectedValue = dai.AliasCulture;
                            pageTitleTabs[1, 0] = addAlias = dai.AliasURLPath;
                        }
                    }                   
                }

                pageAlias.Breadcrumbs = pageTitleTabs;
            }
        }
    }


    protected void btnOK_Click(object sender, EventArgs e)
    {
        DocumentAliasInfo dai = null ;

        // Edit existing alias
        if (aliasId > 0 )
        {
            dai = DocumentAliasInfoProvider.GetDocumentAliasInfo(aliasId);
          
        }

        if (dai == null)
        {
            dai = new DocumentAliasInfo();
        }

        // Add "/" if not present
        string urlPath = txtURLPath.Text.Trim();
        if (!urlPath.StartsWith("/"))
        {
            urlPath = "/" + urlPath;
        }

        // Set object properties
        dai.AliasURLPath = urlPath;
        dai.AliasCampaign = txtTrackCampaign.Text.Trim();
        dai.AliasExtensions = txtURLExtensions.Text.Trim();
        dai.AliasCulture = drpDocumentCulture.Text.Trim();
        dai.AliasSiteID = CMSContext.CurrentSite.SiteID;

        if (nodeId > 0)
        {
            dai.AliasNodeID = nodeId;
        }
        

        //Insert into database
        dai.SetObject();

        // Log synchronization
        DocumentHelper.LogSynchronization(node, TaskTypeEnum.UpdateDocument, tree, SynchronizationInfoProvider.ENABLED_SERVERS);

        nodeId = dai.AliasNodeID;
        aliasId = dai.AliasID; 
        UrlHelper.Redirect("Alias_Edit.aspx?saved=1&nodeid=" + nodeId.ToString() + "&aliasid=" + aliasId.ToString()); 
    }
    
}
