using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.Forums;
using CMS.CMSHelper;
using CMS.UIControls;
using CMS.ExtendedControls;

public partial class CMSModules_Forums_Controls_LiveControls_Posts : CMSAdminItemsControl
{

    #region "Variables"

    private int mForumId = 0;
    private int postId = 0;
    private ForumPostInfo post = null;
    private const string breadCrumbsSeparator = " <span class=\"TitleBreadCrumbSeparator\">&nbsp;</span> ";

    #endregion


    #region "Public properties"

    /// <summary>
    /// Gets or sets the Forum ID.
    /// </summary>
    public int ForumID
    {
        get
        {
            return this.mForumId;
        }
        set
        {
            this.mForumId = value;
        }
    }

    #endregion


    


    protected override void OnLoad(EventArgs e)
    {
        base.OnLoad(e);

        #region "Security"

        postEdit.OnCheckPermissions += new CheckPermissionsEventHandler(postEdit_OnCheckPermissions);
        postNew.OnCheckPermissions += new CheckPermissionsEventHandler(postNew_OnCheckPermissions);

        #endregion

        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "ForumPostPostback_value", ScriptHelper.GetScript(
            "function ShowPost(showId){ \n" +
            "    var hidden = document.getElementById('" + this.hdnPost.ClientID + "'); \n" +
            "    if (hidden != null) { \n" +
            "    hidden.value = showId \n" +
            "    } \n" +  CMS.ExtendedControls.ControlsHelper.GetPostBackEventReference(this, null) +
            "} \n"));

        this.treeElem.ForumID = this.mForumId;
        this.treeElem.SelectOnlyApproved = false;
        this.treeElem.Selected = 0;

        this.postNew.Visible = true;
        this.postNew.ForumID = this.mForumId;
        this.postNew.OnInsertPost += new EventHandler(postNew_OnInsertPost);
        this.postNew.OnPreview += new EventHandler(postNew_OnPreview);
        this.postEdit.OnPreview += new EventHandler(postEdit_OnPreview);
        this.postEdit.OnCancelClick += new EventHandler(postEdit_OnCancelClick);
        this.postEdit.OnSaved += new EventHandler(postEdit_OnSaved);

        UniGrid.Visible = false;
        UniGrid.Query = "";
        postId = ValidationHelper.GetInteger(this.hdnPost.Value, 0);
        if (postId > 0)
        {
            this.plcPostView.Visible = true;
            post = ForumPostInfoProvider.GetForumPostInfo(postId);
            this.treeElem.Selected = postId;
            this.postEdit.EditPostID = postId;
            this.postView.PostID = postId;

            if ((post != null) && (post.PostAttachmentCount > 0))
            {
                string where = "(AttachmentPostID = " + postId + ")";

                // Load unigrid
                UniGrid.WhereCondition = where;
                UniGrid.Query = "Forums.ForumAttachment.selectall";
                UniGrid.OnAction += new OnActionEventHandler(UniGrid_OnAction);
                UniGrid.OnExternalDataBound += new OnExternalDataBoundEventHandler(UniGrid_OnExternalDataBound);
                UniGrid.DataBind();
                UniGrid.ReloadData();
                UniGrid.Visible = true;
            }            
        }
        else
        {
            postNew.ReplyToPostID = 0;
            this.plcPostNew.Visible = true;
        }

        this.plcPostEdit.Visible = false;        
       
        if (post != null)
        {
            InitializeMenu();
        }

        this.titleViewElem.TitleText = ResHelper.GetString("ForumPost_View.PostTitleText");
        this.titleViewElem.TitleImage = UrlHelper.ImagesDirectory + "/CMSModules/Forums/Tools/Posts/post.gif";
        this.titleEditElem.TitleText = ResHelper.GetString("ForumPost_Edit.HeaderCaption");
        this.titleEditElem.TitleImage = UrlHelper.ImagesDirectory + "/CMSModules/Forums/Tools/Posts/post.gif";
        this.lnkEditBack.Text = ResHelper.GetString("general.view");
        this.lnkEditBack.Click += new EventHandler(lnkEditBack_Click);
        if (post != null)
        {
            lblEditBack.Text = breadCrumbsSeparator + HTMLHelper.HTMLEncode(post.PostSubject);
        }

        treeElem.OnGetPostIconUrl += new CMSForum_PostTree.GetIconEventHandler(treeElem_OnGetPostIconUrl);
    }



    #region "Security handlers"

    void postNew_OnCheckPermissions(string permissionType, CMSAdminControl sender)
    {
        RaiseOnCheckPermissions(permissionType, sender);
    }


    void postEdit_OnCheckPermissions(string permissionType, CMSAdminControl sender)
    {
        RaiseOnCheckPermissions(permissionType, sender);
    }

    #endregion


    /// <summary>
    /// Unigrid External bound event handler.
    /// </summary>
    object UniGrid_OnExternalDataBound(object sender, string sourceName, object parameter)
    {
        // Display link instead of title
        if (sourceName.ToLower() == "title")
        {
            if (parameter != DBNull.Value)
            {
                DataRowView row = (DataRowView)parameter;

                // Get info
                ForumAttachmentInfo fai = ForumAttachmentInfoProvider.GetForumAttachmentInfo(ValidationHelper.GetInteger(row["AttachmentID"], 0));

                if (fai != null)
                {
                    string url = UrlHelper.GetAbsoluteUrl("~/CMSModules/Forums/CMSPages/GetForumAttachment.aspx?fileguid=" + fai.AttachmentGUID);
                    string title = ValidationHelper.GetString(row["AttachmentFileName"], "");

                    // Create link to post attachment
                    HyperLink link = new HyperLink();
                    link.NavigateUrl = url;
                    link.Target = "_blank";
                    link.Text = HTMLHelper.HTMLEncode(title);
                    link.ToolTip = url;
                    return link;
                }
            }
        }

        return parameter.ToString();
    }


    /// <summary>
    /// Unigrid Action event handler.
    /// </summary>
    void UniGrid_OnAction(string actionName, object actionArgument)
    {
        if (actionName == "delete")
        {
            if (!CheckPermissions("cms.forums", CMSAdminControl.PERMISSION_MODIFY))
            {
                return;
            }

            ForumAttachmentInfoProvider.DeleteForumAttachmentInfo(ValidationHelper.GetInteger(actionArgument, 0));
        }
    }


    protected void postNew_OnPreview(object sender, EventArgs e)
    {
        this.plcPostEdit.Visible = false;
        this.plcPostView.Visible = false;
        this.plcPostNew.Visible = true;
    }


    void postEdit_OnCancelClick(object sender, EventArgs e)
    {

        this.postEdit.ClearForm();
        this.plcPostEdit.Visible = false;
        this.plcPostView.Visible = true;
        this.plcPostNew.Visible = false;
    }


    protected void postEdit_OnPreview(object sender, EventArgs e)
    {
        this.plcPostEdit.Visible = true;
        this.plcPostView.Visible = false;
        this.plcPostNew.Visible = false;
    }


    protected void postEdit_OnSaved(object sender, EventArgs e)
    {
        this.plcPostEdit.Visible = false;
        this.plcPostView.Visible = true;
        this.plcPostNew.Visible = false;
    }


    protected void postNew_OnInsertPost(object sender, EventArgs e)
    {

        postId = this.postNew.EditPostID;

        this.plcPostEdit.Visible = false;
        this.plcPostView.Visible = true;
        this.plcPostNew.Visible = false;
        this.treeElem.Selected = postId;
        this.postEdit.EditPostID = postId;
        this.postView.PostID = postId;
        this.postNew.ReplyToPostID = 0;

        post = ForumPostInfoProvider.GetForumPostInfo(postId);
        ReloadData();

        this.hdnPost.Value = postId.ToString();

    }


    /// <summary>
    /// Reloads the form data.
    /// </summary>
    public void ReloadData()
    {
        this.hdnPost.Value = null;
        this.treeElem.ForumID = this.mForumId;
        this.postNew.ForumID = this.mForumId;
        this.postEdit.ForumID = this.mForumId;
        this.postEdit.ReloadData();
        this.postNew.ReloadData();

        if (post != null)
        {
            InitializeMenu();
            this.actionsElem.ReloadData();
        }

    }


    /// <summary>
    /// Shows the default view.
    /// </summary>
    public void ShowDefault()
    {
        this.hdnPost.Value = null;
        postId = 0;
        this.plcPostEdit.Visible = false;
        this.plcPostView.Visible = false;
        this.plcPostNew.Visible = true;
        this.postNew.ClearForm();
        this.postEdit.ClearForm();
    }


    /// <summary>
    /// Initializes the menu.
    /// </summary>
    protected void InitializeMenu()
    {

        string[,] actions = new string[10, 11];
        string imagesUrl = ResolveUrl(UrlHelper.ImagesDirectory + "/CMSModules/Forums/Tools/Posts/");

        int i = 0;

        // Edit
        actions[i, 0] = HeaderActions.TYPE_LINKBUTTON;
        actions[i, 1] = ResHelper.GetString("general.edit");
        actions[i, 4] = ResHelper.GetString("ForumPost_View.EditToolTip");
        actions[i, 5] = imagesUrl + "edit16.gif";
        actions[i, 6] = "edit";
        i++;

        // Delete
        actions[i, 0] = HeaderActions.TYPE_LINKBUTTON;
        actions[i, 1] = ResHelper.GetString("general.delete");
        actions[i, 2] = "if (!confirm(" + ScriptHelper.GetString(ResHelper.GetString("ForumPost_View.DeleteConfirmation")) + ")){return false;}";
        actions[i, 4] = ResHelper.GetString("ForumPost_View.DeleteToolTip");
        actions[i, 5] = imagesUrl + "delete16.gif";
        actions[i, 6] = "delete";
        i++;

        // Reply
        actions[i, 0] = HeaderActions.TYPE_LINKBUTTON;
        actions[i, 1] = ResHelper.GetString("ForumPost_View.IconReply");
        actions[i, 4] = ResHelper.GetString("ForumPost_View.ReplyToolTip");
        actions[i, 5] = imagesUrl + "reply16.gif";
        actions[i, 6] = "reply";
        i++;

        if (post.PostLevel == 0)
        {

            // Lock
            actions[i, 0] = HeaderActions.TYPE_LINKBUTTON;
            actions[i, 1] = ResHelper.GetString("ForumPost_View.IconLock");
            actions[i, 4] = ResHelper.GetString("ForumPost_View.LockToolTip");
            actions[i, 5] = imagesUrl + "lock16.gif";
            actions[i, 6] = "lockunlock";
            actions[i, 10] = Convert.ToString((post != null) && !post.PostIsLocked);
            i++;

            // UnLock
            actions[i, 0] = HeaderActions.TYPE_LINKBUTTON;
            actions[i, 1] = ResHelper.GetString("ForumPost_View.IconUnLock");
            actions[i, 4] = ResHelper.GetString("ForumPost_View.UnLockToolTip");
            actions[i, 5] = imagesUrl + "unlock16.gif";
            actions[i, 6] = "lockunlock";
            actions[i, 10] = Convert.ToString((post != null) && post.PostIsLocked);
            i++;

            // Stick
            actions[i, 0] = HeaderActions.TYPE_LINKBUTTON;
            actions[i, 1] = ResHelper.GetString("ForumPost_View.IconStick");
            actions[i, 4] = ResHelper.GetString("ForumPost_View.StickToolTip");
            actions[i, 5] = imagesUrl + "stick16.gif";
            actions[i, 6] = "stick";
            actions[i, 10] = Convert.ToString((post != null) && (post.PostStickOrder <= 0));
            i++;

            // UnStick
            actions[i, 0] = HeaderActions.TYPE_LINKBUTTON;
            actions[i, 1] = ResHelper.GetString("ForumPost_View.IconUnStick");
            actions[i, 4] = ResHelper.GetString("ForumPost_View.UnStickToolTip");
            actions[i, 5] = imagesUrl + "unstick16.gif";
            actions[i, 6] = "unstick";
            actions[i, 10] = Convert.ToString((post != null) && (post.PostStickOrder > 0));
            i++;

        }
        else
        {
            // Split
            actions[i, 0] = HeaderActions.TYPE_LINKBUTTON;
            actions[i, 1] = ResHelper.GetString("ForumPost_View.IconSplit");
            actions[i, 4] = ResHelper.GetString("ForumPost_View.SplitToolTip");
            actions[i, 5] = imagesUrl + "split16.gif";
            actions[i, 6] = "split";
            i++;
        }

        // Approve / reject
        actions[i, 0] = HeaderActions.TYPE_LINKBUTTON;

        if (!post.PostApproved)
        {
            actions[i, 1] = ResHelper.GetString("general.approve");
            actions[i, 4] = ResHelper.GetString("ForumPost_View.ApproveToolTip");
            actions[i, 5] = imagesUrl + "approve16.gif";
            actions[i, 6] = "approve";

        }
        else
        {
            actions[i, 1] = ResHelper.GetString("general.reject");
            actions[i, 4] = ResHelper.GetString("ForumPost_View.RejectToolTip");
            actions[i, 5] = imagesUrl + "reject16.gif";
            actions[i, 6] = "reject";
        }
        i++;

        // Approve subtree
        if (!post.PostApproved)
        {
            actions[i, 0] = HeaderActions.TYPE_LINKBUTTON;
            actions[i, 1] = ResHelper.GetString("ForumPost_View.IconApproveSubTree");
            actions[i, 4] = ResHelper.GetString("ForumPost_View.ApproveSubTreeToolTip");
            actions[i, 5] = imagesUrl + "approve16.gif";
            actions[i, 6] = "approvesubtree";
        }
        else
        {
            actions[i, 0] = HeaderActions.TYPE_LINKBUTTON;
            actions[i, 1] = ResHelper.GetString("ForumPost_View.IconRejectSubTree");
            actions[i, 4] = ResHelper.GetString("ForumPost_View.RejectSubTreeToolTip");
            actions[i, 5] = imagesUrl + "reject16.gif";
            actions[i, 6] = "rejectsubtree";
        }

        i++;

        this.actionsElem.Actions = actions;
        this.actionsElem.ActionPerformed += new CommandEventHandler(actionsElem_ActionPerformed);

    }


    /// <summary>
    /// Handle actions
    /// </summary>
    protected void actionsElem_ActionPerformed(object sender, CommandEventArgs e)
    {
        if (!CheckPermissions("cms.forums", CMSAdminControl.PERMISSION_MODIFY))
        {
            return;
        }

        switch (e.CommandName.ToLower())
        {
            case "stick":

                ForumPostInfoProvider.StickThread(post);

                // Get the post object with updated info
                post = ForumPostInfoProvider.GetForumPostInfo(post.PostId);

                ReloadData();

                break;

            case "unstick":

                ForumPostInfoProvider.UnstickThread(post);

                // Get the post object with updated info
                post = ForumPostInfoProvider.GetForumPostInfo(post.PostId);

                ReloadData();

                break;

            case "split":

                ForumPostInfoProvider.SplitThread(post);

                // Get the post object with updated info
                post = ForumPostInfoProvider.GetForumPostInfo(post.PostId);

                ReloadData();

                break;

            case "lockunlock":

                post.PostIsLocked = !post.PostIsLocked;
                ForumPostInfoProvider.SetForumPostInfo(post);

                ReloadData();

                break;

            case "edit":

                this.plcPostEdit.Visible = true;
                this.plcPostView.Visible = false;
                this.plcPostNew.Visible = false;

                break;

            case "delete":

                ForumPostInfoProvider.DeleteForumPostInfo(postId);
                this.hdnPost.Value = null;
                this.plcPostEdit.Visible = false;
                this.plcPostView.Visible = false;
                this.plcPostNew.Visible = true;
                this.postNew.ClearForm();

                break;

            case "reply":

                this.plcPostEdit.Visible = false;
                this.plcPostView.Visible = false;
                this.plcPostNew.Visible = true;
                this.postNew.ClearForm();
                this.postNew.Visible = true;
                this.postNew.ReplyToPostID = postId;
                this.postNew.ReloadData();

                break;

            case "approve":

                if (CMSContext.CurrentUser != null)
                {
                    post.PostApprovedByUserID = CMSContext.CurrentUser.UserID;
                    post.PostApproved = true;
                    ForumPostInfoProvider.SetForumPostInfo(post);
                }

                ReloadData();

                break;

            case "reject":

                post.PostApprovedByUserID = 0;
                post.PostApproved = false;
                ForumPostInfoProvider.SetForumPostInfo(post);

                ReloadData();

                break;

            case "approvesubtree":

                if ((post != null) && (CMSContext.CurrentUser != null))
                {
                    post.PostApprovedByUserID = CMSContext.CurrentUser.UserID;
                    post.PostApproved = true;
                    ForumPostInfoProvider.SetForumPostInfo(post);

                    DataSet ds = ForumPostInfoProvider.GetChildPosts(post.PostId);

                    if (!DataHelper.DataSourceIsEmpty(ds))
                    {
                        foreach (DataRow dr in ds.Tables[0].Rows)
                        {
                            ForumPostInfo mfpi = new ForumPostInfo(dr);
                            if ((mfpi != null) && (!mfpi.PostApproved))
                            {
                                mfpi.PostApprovedByUserID = CMSContext.CurrentUser.UserID;
                                mfpi.PostApproved = true;
                                ForumPostInfoProvider.SetForumPostInfo(mfpi);
                            }
                        }
                    }

                    ReloadData();

                }

                break;

            case "rejectsubtree":

                if (post != null)
                {
                    post.PostApprovedByUserID = 0;
                    post.PostApproved = false;
                    ForumPostInfoProvider.SetForumPostInfo(post);

                    DataSet ds = ForumPostInfoProvider.GetChildPosts(post.PostId);

                    if (!DataHelper.DataSourceIsEmpty(ds))
                    {
                        foreach (DataRow dr in ds.Tables[0].Rows)
                        {
                            ForumPostInfo mfpi = new ForumPostInfo(dr);
                            if ((mfpi != null) && (mfpi.PostApproved))
                            {
                                mfpi.PostApprovedByUserID = 0;
                                mfpi.PostApproved = false;
                                ForumPostInfoProvider.SetForumPostInfo(mfpi);
                            }
                        }
                    }
                    ReloadData();
                }

                break;

        }

        this.hdnPost.Value = postId.ToString();

    }


    protected void lnkEditBack_Click(object sender, EventArgs e)
    {
        this.plcPostEdit.Visible = false;
        this.plcPostView.Visible = true;
        this.plcPostNew.Visible = false;
    }


    protected string treeElem_OnGetPostIconUrl(CMS.Forums.ForumPostTreeNode node)
    {
        string imageUrl = "";

        if (node != null)
        {
            imageUrl = ResolveUrl(UrlHelper.ImagesDirectory + "/CMSModules/Forums/Tools/Posts/post16.gif");
            if (!ValidationHelper.GetBoolean(((DataRow)node.ItemData)["PostApproved"], false))
            {

                imageUrl = ResolveUrl(UrlHelper.ImagesDirectory + "/CMSModules/Forums/Tools/Posts/rejected16.gif");
            }
        }

        return imageUrl;
    }


    protected override void OnPreRender(EventArgs e)
    {
        base.OnPreRender(e);

        if (ControlsHelper.IsInUpdatePanel(this))
        {
            ControlsHelper.UpdateCurrentPanel(this);
        }
    }
}
